==> sight_21.0.0.orig.tar.gz: sight-21.0.0/libs/core/core/test/api/tools/UUIDTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2021 IRCAD France
 * Copyright (C) 2012-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <core/tools/Object.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::core::tools
{

namespace ut
{

class UUIDTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(UUIDTest);
CPPUNIT_TEST(objectUUIDTest);
CPPUNIT_TEST(conccurentAccessOnUUIDMapTest);
CPPUNIT_TEST(conccurentAccessOnSameObjUUIDTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp();
    void tearDown();

    void objectUUIDTest();

    void conccurentAccessOnUUIDMapTest();
    void conccurentAccessOnSameObjUUIDTest();

private:

    void runUUIDCreation();
    void runAccessToObjectUUID();

    core::tools::Object::sptr m_object;
    std::string m_uuid;
};

} // namespace ut

} // namespace sight::core::tools

==> sight_23.1.0.orig.tar.gz: sight-23.1.0/libs/core/core/test/api/tools/UUIDTest.hpp <==
/************************************************************************
 *
 * Copyright (C) 2009-2022 IRCAD France
 * Copyright (C) 2012-2021 IHU Strasbourg
 *
 * This file is part of Sight.
 *
 * Sight is free software: you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Sight is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
 *
 ***********************************************************************/

#pragma once

#include <core/tools/Object.hpp>

#include <cppunit/extensions/HelperMacros.h>

namespace sight::core::tools::ut
{

class UUIDTest : public CPPUNIT_NS::TestFixture
{
CPPUNIT_TEST_SUITE(UUIDTest);
CPPUNIT_TEST(objectUUIDTest);
CPPUNIT_TEST(conccurentAccessOnUUIDMapTest);
CPPUNIT_TEST(conccurentAccessOnSameObjUUIDTest);
CPPUNIT_TEST_SUITE_END();

public:

    // interface
    void setUp() override;
    void tearDown() override;

    static void objectUUIDTest();

    static void conccurentAccessOnUUIDMapTest();
    void conccurentAccessOnSameObjUUIDTest();

private:

    static void runUUIDCreation();
    void runAccessToObjectUUID();

    core::tools::Object::sptr m_object;
    std::string m_uuid;
};

} // namespace sight::core::tools::ut
